<?php

/*
RBookmarks
Copyright (C) 2001-2002  Ragnar Ouchterlony

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

$category_hierarchy = array();

class Category
{
  var $id;
  var $name;

  var $parent;
  var $children;

  function Category( $_id, $_name, $_parent )
    {
      $this->id = $_id;
      $this->name = $_name;

      $this->parent = $_parent;
      $this->children = array();
    }

  function add_child( $child_id )
    {
      array_push( $this->children, $child_id );
    }

  function get_name_with_parents()
    {
      global $category_hierarchy;

      $result = '';
      if( !is_null( $this->parent ) )
        $result = $category_hierarchy[ $this->parent ]->get_name_with_parents() . '::';

      return $result . $this->name;
    }

  function do_and_propagate_to_children( $func, $propagate_after = true, $test_func = null )
    {
      global $category_hierarchy;

      if( $propagate_after )
        call_user_func( $func, $this );

      foreach( $this->children as $child )
        {
          if( is_null($test_func) ||
              call_user_func( $test_func, $category_hierarchy[ $child ] ) )
            {
              $category_hierarchy[ $child ]->do_and_propagate_to_children( $func,
                                                                           $propagate_after,
                                                                           $test_func );
            }
        }

      if( !$propagate_after )
        call_user_func( $func, $this );
    }

  function count_ancestors()
    {
      global $category_hierarchy;

      if( is_null($this->parent) )
        return 0;

      return ($category_hierarchy[ $this->parent]->count_ancestors() + 1);
    }

  function is_top()
    {
      return is_null($this->parent);
    }
}

function create_categories( $force = false )
{
  global $category_hierarchy;

  if( (!empty( $category_hierarchy ) && !$force) )
    return;

  $category_hierarchy = array();

  $query_result = mysql_query( "SELECT * FROM category ORDER BY name, parent" );
  while( $row = mysql_fetch_array($query_result) )
    {
      $category_hierarchy[ $row['id'] ] =
        new Category( $row['id'], $row['name'], $row['parent'] );
    }

  $category_hierarchy[0] = new Category( 0, null, null );

  foreach( $category_hierarchy as $id => $category )
    {
      if( !is_null( $category->parent ) )
        $category_hierarchy[ $category->parent ]->add_child( $id );
      elseif( $id != 0 )
        $category_hierarchy[0]->add_child( $id );
    }

}

?>
