<?php

/*
RBookmarks
Copyright (C) 2001-2002  Ragnar Ouchterlony

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

class BArray
{
  var $the_array;

  function BArray()
    {
      $this->the_array = array();
    }

  function set_from_string( $array_string )
    {
      if( !empty( $array_string ) )
        $this->the_array = explode( ".", $array_string );
      else
        $this->the_array = array();
    }

  function set_from_array( $new_array )
    {
      $this->the_array = $new_array;
    }

  function add_element( $element )
    {
      $this->the_array = array_merge( $this->the_array, array( $element ) );
    }

  function remove_element( $element )
    {
      $this->the_array = array_diff( $this->the_array, array( $element ) );
    }

  function get_as_string()
    {
      return implode( '.', $this->the_array );
    }

  function is_empty()
    {
      return empty($this->the_array);
    }
}

class Options
{
  var $collapsed_categories;
  var $include_subcategories;
  var $dots;
  var $changelink;
  var $use_filters;
  var $always_save_state;
  var $static;

  function Options()
    {
      global $collapsed_categories, $include_subcategories, $dot_subcategories,
        $display_chaneglink, $use_filter_functionality, $always_remember_state;

      $this->collapsed_categories = $collapsed_categories;
      $this->include_subcategories = $include_subcategories;
      $this->dots = $dot_subcategories;
      $this->changelink = $display_chaneglink;
      $this->use_filters = $use_filter_functionality;
      $this->always_save_state = $always_remember_state;
      $this->static = false;
    }

  function set_from_string( $options_string )
    {
      $this->collapse_categories =
                           ( strpos( $options_string, 'c' ) === false ? false : true );
      $this->include_subcategories =
                           ( strpos( $options_string, 'i' ) === false ? false : true );
      $this->dots        = ( strpos( $options_string, 'd' ) === false ? false : true );
      $this->static      = ( strpos( $options_string, 's' ) === false ? false : true );
      $this->disp_clink  = ( strpos( $options_string, 'h' ) === false ? false : true );
      $this->always_save_state =
                           ( strpos( $options_string, 'a' ) === false ? false : true );
      $this->use_filters = ( strpos( $options_string, 'f' ) === false ? false : true );
    }

  function as_string()
    {
      $options =
        "_".
        ( $this->collapse_categories   ? 'c' : '' ).
        ( $this->include_subcategories ? 'i' : '' ).
        ( $this->dots                  ? 'd' : '' ).
        ( $this->changelink            ? 'h' : '' ).
        ( $this->always_save_state     ? 'a' : '' ).
        ( $this->use_filters           ? 'f' : '' ).
        "_";
      return $options;
    }
}

class PageState
{
  var $current_category;
  var $cc_array;
  var $filter_array;
  var $options;

  function PageState()
    {
      global $default_category;

      $this->current_category = $default_category;
      $this->options = new Options;
      $this->cc_array = new BArray;
      $this->filter_array = new BArray;
    }

  function set_new_category( $new_category )
    {
      $this->current_category = $new_category;
    }

  function set_new_options( $new_options )
    {
      $this->options->set_from_string( $new_options );
    }

  function set_new_cc_str( $new_cc_str )
    {
      $this->cc_array->set_from_string( $new_cc_str );
    }

  function set_new_filter_str( $new_filter_str )
    {
      if( $this->options->use_filters )
        $this->filter_array->set_from_string( $new_filter_str );
    }
}

?>
